[![FactSet](https://raw.githubusercontent.com/factset/enterprise-sdk/main/docs/images/factset-logo.svg)](https://www.factset.com)

# Events and Transcripts client library for Python

[![API Version](https://img.shields.io/badge/api-v2.2.0-blue)](https://developer.factset.com/api-catalog/documents-distributor-callstreet-events)
[![PyPi](https://img.shields.io/pypi/v/fds.sdk.EventsandTranscripts/2.1.1)](https://pypi.org/project/fds.sdk.EventsandTranscripts/v/2.1.1)
[![Apache-2 license](https://img.shields.io/badge/license-Apache2-brightgreen.svg)](https://www.apache.org/licenses/LICENSE-2.0)

<p>The Calendar Events API provides access to FactSetâ€™s Event Calendar data alongside business logic that allows users to replicate views and functionality consistent with the experience provided by the Workstation. This API provides the ability to pull Event Calendar data based on specific filters.</p>
<p>Events Audio API provides access to historical as well as the latest audio recordings of various company events covered by FactSet. The events include, but are not limited to: earnings calls, conferences, and investor days. This API also provides relevant metadata such as timestamps and identifiers around each audio file.</p>
<p>The  Near Real-time Transcripts API enables access to Near Real-time Transcripts provided by CallStreet to time-sensitive clients. This API also provides the relevant speaker metadata along with their confidence scores. This data caters to quant clients interested in building machine learning models. Clients can leverage this API to perform sentiment analysis through natural language processing or machine learning. It can also be used to complement analysis using FactSet's transcripts service.</p>
<p>Transcripts API provides conference call transcripts for companies' publicly held conference calls and a wealth of information regarding upcoming corporate events, such as conference call date and time, phone number and password, type of conference call, and important company investor relations contact information.</p>


This Python package is automatically generated by the [OpenAPI Generator](https://openapi-generator.tech) project:

- API version: 2.2.0
- SDK version: 2.1.1
- Build package: org.openapitools.codegen.languages.PythonClientCodegen

For more information, please visit [https://developer.factset.com/contact](https://developer.factset.com/contact)

## Requirements

* Python >= 3.7

## Installation

### Poetry

```shell
poetry add fds.sdk.utils fds.sdk.EventsandTranscripts==2.1.1
```

### pip

```shell
pip install fds.sdk.utils fds.sdk.EventsandTranscripts==2.1.1
```

## Usage

1. [Generate authentication credentials](../../../../README.md#authentication).
2. Setup Python environment.
   1. Install and activate python 3.7+. If you're using [pyenv](https://github.com/pyenv/pyenv):

      ```sh
      pyenv install 3.9.7
      pyenv shell 3.9.7
      ```

   2. (optional) [Install poetry](https://python-poetry.org/docs/#installation).
3. [Install dependencies](#installation).
4. Run the following:

> [!IMPORTANT]
> The parameter variables defined below are just examples and may potentially contain non valid values. Please replace them with valid values.

### Example Code

```python
from fds.sdk.utils.authentication import ConfidentialClient

import fds.sdk.EventsandTranscripts
from fds.sdk.EventsandTranscripts.api import calendar_events_api
from fds.sdk.EventsandTranscripts.models import *
from dateutil.parser import parse as dateutil_parser
from pprint import pprint

# See configuration.py for a list of all supported configuration parameters.

# Examples for each supported authentication method are below,
# choose one that satisfies your use case.

# (Preferred) OAuth 2.0: FactSetOAuth2
# See https://github.com/FactSet/enterprise-sdk#oauth-20
# for information on how to create the app-config.json file
#
# The confidential client instance should be reused in production environments.
# See https://github.com/FactSet/enterprise-sdk-utils-python#authentication
# for more information on using the ConfidentialClient class
configuration = fds.sdk.EventsandTranscripts.Configuration(
    fds_oauth_client=ConfidentialClient('/path/to/app-config.json')
)

# Basic authentication: FactSetApiKey
# See https://github.com/FactSet/enterprise-sdk#api-key
# for information how to create an API key
# configuration = fds.sdk.EventsandTranscripts.Configuration(
#     username='USERNAME-SERIAL',
#     password='API-KEY'
# )

# Enter a context with an instance of the API client
with fds.sdk.EventsandTranscripts.ApiClient(configuration) as api_client:
    # Create an instance of the API class
    api_instance = calendar_events_api.CalendarEventsApi(api_client)
    company_event_request = CompanyEventRequest(
        data=CompanyEventRequestData(
            date_time=CompanyEventRequestDataDateTime(
                start=dateutil_parser('2022-12-01T00:00:00Z'),
                end=dateutil_parser('2022-12-31T22:59:02Z'),
            ),
            universe=CompanyEventRequestDataUniverse(
                symbols=["AAPL-US","MSFT-US","FDS-US"],
                type="Tickers",
            ),
            event_types=[
                "Earnings",
            ],
            last_modified_within="Today",
        ),
    ) # CompanyEventRequest | Company Events request body

    try:
        # Retrieve Company Event data
        # example passing only required values which don't have defaults set
        api_response = api_instance.get_company_event(company_event_request)

        pprint(api_response)
    except fds.sdk.EventsandTranscripts.ApiException as e:
        print("Exception when calling CalendarEventsApi->get_company_event: %s\n" % e)

    # # Get response, http status code and response headers
    # try:
    #     # Retrieve Company Event data
    #     api_response, http_status_code, response_headers = api_instance.get_company_event_with_http_info(company_event_request)


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.EventsandTranscripts.ApiException as e:
    #     print("Exception when calling CalendarEventsApi->get_company_event: %s\n" % e)

    # # Get response asynchronous
    # try:
    #     # Retrieve Company Event data
    #     async_result = api_instance.get_company_event_async(company_event_request)
    #     api_response = async_result.get()


    #     pprint(api_response)
    # except fds.sdk.EventsandTranscripts.ApiException as e:
    #     print("Exception when calling CalendarEventsApi->get_company_event: %s\n" % e)

    # # Get response, http status code and response headers asynchronous
    # try:
    #     # Retrieve Company Event data
    #     async_result = api_instance.get_company_event_with_http_info_async(company_event_request)
    #     api_response, http_status_code, response_headers = async_result.get()


    #     pprint(api_response)
    #     pprint(http_status_code)
    #     pprint(response_headers)
    # except fds.sdk.EventsandTranscripts.ApiException as e:
    #     print("Exception when calling CalendarEventsApi->get_company_event: %s\n" % e)

```

### Using Pandas

To convert an API response to a Pandas DataFrame, it is necessary to transform it first to a dictionary.
```python
import pandas as pd

response_dict = api_response.to_dict()['data']

simple_json_response = pd.DataFrame(response_dict)
nested_json_response = pd.json_normalize(response_dict)
```

### Debugging

The SDK uses the standard library [`logging`](https://docs.python.org/3/library/logging.html#module-logging) module.

Setting `debug` to `True` on an instance of the `Configuration` class sets the log-level of related packages to `DEBUG`
and enables additional logging in Pythons [HTTP Client](https://docs.python.org/3/library/http.client.html).

**Note**: This prints out sensitive information (e.g. the full request and response). Use with care.

```python
import logging
import fds.sdk.EventsandTranscripts

logging.basicConfig(level=logging.DEBUG)

configuration = fds.sdk.EventsandTranscripts.Configuration(...)
configuration.debug = True
```

### Configure a Proxy

You can pass proxy settings to the Configuration class:

* `proxy`: The URL of the proxy to use.
* `proxy_headers`: a dictionary to pass additional headers to the proxy (e.g. `Proxy-Authorization`).

```python
import fds.sdk.EventsandTranscripts

configuration = fds.sdk.EventsandTranscripts.Configuration(
    # ...
    proxy="http://secret:password@localhost:5050",
    proxy_headers={
        "Custom-Proxy-Header": "Custom-Proxy-Header-Value"
    }
)
```

### Custom SSL Certificate

TLS/SSL certificate verification can be configured with the following Configuration parameters:

* `ssl_ca_cert`: a path to the certificate to use for verification in `PEM` format.
* `verify_ssl`: setting this to `False` disables the verification of certificates.
  Disabling the verification is not recommended, but it might be useful during
  local development or testing.

```python
import fds.sdk.EventsandTranscripts

configuration = fds.sdk.EventsandTranscripts.Configuration(
    # ...
    ssl_ca_cert='/path/to/ca.pem'
)
```

### Request Retries

In case the request retry behaviour should be customized, it is possible to pass a `urllib3.Retry` object to the `retry` property of the Configuration.

```python
from urllib3 import Retry
import fds.sdk.EventsandTranscripts

configuration = fds.sdk.EventsandTranscripts.Configuration(
    # ...
)

configuration.retries = Retry(total=3, status_forcelist=[500, 502, 503, 504])
```


## Documentation for API Endpoints

All URIs are relative to *https://api.factset.com/content/events/v2*

Class | Method | HTTP request | Description
------------ | ------------- | ------------- | -------------
*CalendarEventsApi* | [**get_company_event**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CalendarEventsApi.md#get_company_event) | **POST** /calendar/events | Retrieve Company Event data
*EventsAudioApi* | [**get_audio_history_files**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/EventsAudioApi.md#get_audio_history_files) | **GET** /audio/history | Retrieve historical audio recordings and related metadata within FactSet coverage.
*EventsAudioApi* | [**search_events_audio**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/EventsAudioApi.md#search_events_audio) | **POST** /audio | Retrieve latest audio recordings and related metadata based on different search criteria.
*MetaApi* | [**get_timezone**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/MetaApi.md#get_timezone) | **GET** /meta/time-zones | Returns the time zones.
*MetaApi* | [**getcategories**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/MetaApi.md#getcategories) | **GET** /meta/categories | Returns the categories.
*NearRealTimeTranscriptsApi* | [**get_indexed_nrt**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NearRealTimeTranscriptsApi.md#get_indexed_nrt) | **GET** /nrt/indexed | Returns the  indexed transcript data  in small increments throughout the duration of an active call.
*NearRealTimeTranscriptsApi* | [**get_speaker_ids**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NearRealTimeTranscriptsApi.md#get_speaker_ids) | **GET** /nrt/speaker-ids | Returns the latest speakerIds with the confidence scores generated for an active call.
*NearRealTimeTranscriptsApi* | [**search_nrt_calls**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NearRealTimeTranscriptsApi.md#search_nrt_calls) | **POST** /nrt/calls | Returns the active calls happening at the moment based on ticker/entity or specific IDs.
*TranscriptsApi* | [**get_transcripts_intelligence**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsApi.md#get_transcripts_intelligence) | **GET** /transcripts/intelligence | Returns the StreetAccount Transcript Intelligence documents and related metadata within FactSet coverage based on specific date range and various parameters.
*TranscriptsApi* | [**get_transcripts_investor_slides**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsApi.md#get_transcripts_investor_slides) | **GET** /transcripts/investor-slides | Returns the investor slides in PDF format and related metadata within FactSet coverage based on specific date range and various parameters.
*TranscriptsApi* | [**get_transcriptsin_xml**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsApi.md#get_transcriptsin_xml) | **GET** /transcripts/response-type | Returns the requested response type of transcript
*TranscriptsApi* | [**search_transcripts**](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsApi.md#search_transcripts) | **POST** /transcripts | Returns transcript documents and related metadata based on different search criteria.


## Documentation For Models

 - [AudioByDateRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioByDateRequest.md)
 - [AudioByFileNameRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioByFileNameRequest.md)
 - [AudioByIdsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioByIdsRequest.md)
 - [AudioByUploadTimeRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioByUploadTimeRequest.md)
 - [AudioRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioRequest.md)
 - [AudioRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioRequestData.md)
 - [AudioRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioRequestMeta.md)
 - [AudioRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioRequestMetaPagination.md)
 - [AudioResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/AudioResponse.md)
 - [Body](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Body.md)
 - [BodyNrt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/BodyNrt.md)
 - [CategoriesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CategoriesResponse.md)
 - [CategoriesResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CategoriesResponseData.md)
 - [CompanyEventRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CompanyEventRequest.md)
 - [CompanyEventRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CompanyEventRequestData.md)
 - [CompanyEventRequestDataDateTime](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CompanyEventRequestDataDateTime.md)
 - [CompanyEventRequestDataUniverse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CompanyEventRequestDataUniverse.md)
 - [CompanyEventResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CompanyEventResponse.md)
 - [CompanyEventResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/CompanyEventResponseData.md)
 - [Document](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Document.md)
 - [DocumentOne](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/DocumentOne.md)
 - [DocumentResult](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/DocumentResult.md)
 - [Error](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Error.md)
 - [ErrorObject](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/ErrorObject.md)
 - [EventsAudioDailyResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/EventsAudioDailyResponseData.md)
 - [EventsAudioHistoryResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/EventsAudioHistoryResponse.md)
 - [EventsAudioHistoryResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/EventsAudioHistoryResponseData.md)
 - [IndexedNrtResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/IndexedNrtResponse.md)
 - [IndexedNrtResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/IndexedNrtResponseData.md)
 - [InvalidIdErrorData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/InvalidIdErrorData.md)
 - [InvestorSlidesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/InvestorSlidesResponse.md)
 - [InvestorSlidesResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/InvestorSlidesResponseData.md)
 - [Meta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Meta.md)
 - [MetaData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/MetaData.md)
 - [MetaDataPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/MetaDataPagination.md)
 - [MetaNrt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/MetaNrt.md)
 - [NRT](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NRT.md)
 - [NrtCallsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsRequest.md)
 - [NrtCallsRequestByIds](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsRequestByIds.md)
 - [NrtCallsRequestByTicker](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsRequestByTicker.md)
 - [NrtCallsRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsRequestData.md)
 - [NrtCallsRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsRequestMeta.md)
 - [NrtCallsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsResponse.md)
 - [NrtCallsResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtCallsResponseData.md)
 - [NrtSpeakerIdsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtSpeakerIdsResponse.md)
 - [NrtSpeakerIdsResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/NrtSpeakerIdsResponseData.md)
 - [Participant](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Participant.md)
 - [ParticipantNrt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/ParticipantNrt.md)
 - [Plist](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Plist.md)
 - [RawOrCorrected](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/RawOrCorrected.md)
 - [ResponseType](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/ResponseType.md)
 - [ResponseTypeData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/ResponseTypeData.md)
 - [Section](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Section.md)
 - [SectionNrt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/SectionNrt.md)
 - [Speaker](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/Speaker.md)
 - [SpeakerNrt](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/SpeakerNrt.md)
 - [TimeZonesResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TimeZonesResponse.md)
 - [TimeZonesResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TimeZonesResponseData.md)
 - [TranscriptsByDateRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsByDateRequest.md)
 - [TranscriptsByEventsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsByEventsRequest.md)
 - [TranscriptsByIdsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsByIdsRequest.md)
 - [TranscriptsByIdsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsByIdsResponse.md)
 - [TranscriptsBySearchRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsBySearchRequest.md)
 - [TranscriptsByTimesRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsByTimesRequest.md)
 - [TranscriptsCollection](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsCollection.md)
 - [TranscriptsIntelligenceResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsIntelligenceResponse.md)
 - [TranscriptsIntelligenceResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsIntelligenceResponseData.md)
 - [TranscriptsRequest](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsRequest.md)
 - [TranscriptsRequestData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsRequestData.md)
 - [TranscriptsRequestMeta](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsRequestMeta.md)
 - [TranscriptsRequestMetaPagination](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsRequestMetaPagination.md)
 - [TranscriptsResponse](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsResponse.md)
 - [TranscriptsResponseData](https://github.com/FactSet/enterprise-sdk/tree/main/code/python/EventsandTranscripts/v2/docs/TranscriptsResponseData.md)


## Documentation For Authorization


## FactSetApiKey

- **Type**: HTTP basic authentication


## FactSetOAuth2

- **Type**: OAuth
- **Flow**: application
- **Authorization URL**: 
- **Scopes**: N/A


## Notes for Large OpenAPI documents
If the OpenAPI document is large, imports in fds.sdk.EventsandTranscripts.apis and fds.sdk.EventsandTranscripts.models may fail with a
RecursionError indicating the maximum recursion limit has been exceeded. In that case, there are a couple of solutions:

Solution 1:
Use specific imports for apis and models like:
- `from fds.sdk.EventsandTranscripts.api.default_api import DefaultApi`
- `from fds.sdk.EventsandTranscripts.model.pet import Pet`

Solution 2:
Before importing the package, adjust the maximum recursion limit as shown below:
```
import sys
sys.setrecursionlimit(1500)
import fds.sdk.EventsandTranscripts
from fds.sdk.EventsandTranscripts.apis import *
from fds.sdk.EventsandTranscripts.models import *
```

## Contributing

Please refer to the [contributing guide](../../../../CONTRIBUTING.md).

## Copyright

Copyright 2026 FactSet Research Systems Inc

Licensed under the Apache License, Version 2.0 (the "License");
you may not use this file except in compliance with the License.
You may obtain a copy of the License at

    http://www.apache.org/licenses/LICENSE-2.0

Unless required by applicable law or agreed to in writing, software
distributed under the License is distributed on an "AS IS" BASIS,
WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
See the License for the specific language governing permissions and
limitations under the License.

